==> jc-1.4.0.tar.gz: soot/toolkits/scalar/ObjectIntMapper.h <==
// class soot.toolkits.scalar.ObjectIntMapper

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bad2891da971eb8a soot_toolkits_scalar_ObjectIntMapper

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_ObjectIntMapper_H_
#define _JC_soot_toolkits_scalar_ObjectIntMapper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Vector$object;
struct _jc_soot_toolkits_scalar_FlowUniverse$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_ObjectIntMapper$sub_refs	_jc_soot_toolkits_scalar_ObjectIntMapper$sub_refs;
typedef struct _jc_soot_toolkits_scalar_ObjectIntMapper$sub_nonrefs	_jc_soot_toolkits_scalar_ObjectIntMapper$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_ObjectIntMapper$refs	_jc_soot_toolkits_scalar_ObjectIntMapper$refs;
typedef struct _jc_soot_toolkits_scalar_ObjectIntMapper$nonrefs	_jc_soot_toolkits_scalar_ObjectIntMapper$nonrefs;
typedef struct _jc_soot_toolkits_scalar_ObjectIntMapper$object	_jc_soot_toolkits_scalar_ObjectIntMapper$object;

typedef const struct _jc_soot_toolkits_scalar_ObjectIntMapper$vmethods	_jc_soot_toolkits_scalar_ObjectIntMapper$vmethods;
typedef const struct _jc_soot_toolkits_scalar_ObjectIntMapper$vtable	_jc_soot_toolkits_scalar_ObjectIntMapper$vtable;
typedef const struct _jc_soot_toolkits_scalar_ObjectIntMapper$vtype	_jc_soot_toolkits_scalar_ObjectIntMapper$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_ObjectIntMapper$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *);
extern void _jc_soot_toolkits_scalar_ObjectIntMapper$method$_init$f10d3ead4f9e91ce(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, struct _jc_object *);
extern void _jc_soot_toolkits_scalar_ObjectIntMapper$method$_init$10c4521778ce6db6(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, struct _jc_object *, jint);
extern void _jc_soot_toolkits_scalar_ObjectIntMapper$method$_init$6f7527dce474d098(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, struct _jc_object *);

// Virtual methods
extern jint _jc_soot_toolkits_scalar_ObjectIntMapper$method$add$c072c3c5381d46e2(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, struct _jc_java_lang_Object$object *);
extern jboolean _jc_soot_toolkits_scalar_ObjectIntMapper$method$contains$d3bd70da40f05cb1(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_soot_toolkits_scalar_ObjectIntMapper$method$getInt$36d310712392733a(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_ObjectIntMapper$method$getObject$a6a0b5ad3557b895(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, jint);
extern jint _jc_soot_toolkits_scalar_ObjectIntMapper$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_ObjectIntMapper$method_info$add$c072c3c5381d46e2;
extern _jc_method _jc_soot_toolkits_scalar_ObjectIntMapper$method_info$contains$d3bd70da40f05cb1;
extern _jc_method _jc_soot_toolkits_scalar_ObjectIntMapper$method_info$getInt$36d310712392733a;
extern _jc_method _jc_soot_toolkits_scalar_ObjectIntMapper$method_info$getObject$a6a0b5ad3557b895;
extern _jc_method _jc_soot_toolkits_scalar_ObjectIntMapper$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_ObjectIntMapper$vmethods {
	jint	(*add$c072c3c5381d46e2)(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, struct _jc_java_lang_Object$object *);
	jboolean	(*contains$d3bd70da40f05cb1)(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, struct _jc_java_lang_Object$object *);
	jint	(*getInt$36d310712392733a)(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*getObject$a6a0b5ad3557b895)(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, jint);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *);
};

// Vtable
struct _jc_soot_toolkits_scalar_ObjectIntMapper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_ObjectIntMapper$vmethods	soot_toolkits_scalar_ObjectIntMapper;
};

// Vtype
struct _jc_soot_toolkits_scalar_ObjectIntMapper$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_ObjectIntMapper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_ObjectIntMapper$sub_refs {
	struct _jc_java_util_Vector$object	*intToObjects;
	struct _jc_object	*objectToInts;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_ObjectIntMapper$refs {
    _jc_soot_toolkits_scalar_ObjectIntMapper$sub_refs	soot_toolkits_scalar_ObjectIntMapper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_ObjectIntMapper$sub_nonrefs {
	jint	counter;
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_ObjectIntMapper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_ObjectIntMapper$sub_nonrefs	soot_toolkits_scalar_ObjectIntMapper;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_ObjectIntMapper$object {
	_jc_soot_toolkits_scalar_ObjectIntMapper$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_ObjectIntMapper$vtype	*vtype;
	_jc_soot_toolkits_scalar_ObjectIntMapper$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_ObjectIntMapper$vtype _jc_soot_toolkits_scalar_ObjectIntMapper$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_ObjectIntMapper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_ObjectIntMapper$class_object;

#endif	/* _JC_soot_toolkits_scalar_ObjectIntMapper_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/ObjectIntMapper.h <==
// class soot.toolkits.scalar.ObjectIntMapper

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bad2891da971eb8a soot_toolkits_scalar_ObjectIntMapper

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_ObjectIntMapper_H_
#define _JC_soot_toolkits_scalar_ObjectIntMapper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Vector$object;
struct _jc_soot_toolkits_scalar_FlowUniverse$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_ObjectIntMapper$sub_refs	_jc_soot_toolkits_scalar_ObjectIntMapper$sub_refs;
typedef struct _jc_soot_toolkits_scalar_ObjectIntMapper$sub_nonrefs	_jc_soot_toolkits_scalar_ObjectIntMapper$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_ObjectIntMapper$refs	_jc_soot_toolkits_scalar_ObjectIntMapper$refs;
typedef struct _jc_soot_toolkits_scalar_ObjectIntMapper$nonrefs	_jc_soot_toolkits_scalar_ObjectIntMapper$nonrefs;
typedef struct _jc_soot_toolkits_scalar_ObjectIntMapper$object	_jc_soot_toolkits_scalar_ObjectIntMapper$object;

typedef const struct _jc_soot_toolkits_scalar_ObjectIntMapper$vmethods	_jc_soot_toolkits_scalar_ObjectIntMapper$vmethods;
typedef const struct _jc_soot_toolkits_scalar_ObjectIntMapper$vtable	_jc_soot_toolkits_scalar_ObjectIntMapper$vtable;
typedef const struct _jc_soot_toolkits_scalar_ObjectIntMapper$vtype	_jc_soot_toolkits_scalar_ObjectIntMapper$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_ObjectIntMapper$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_scalar_ObjectIntMapper$method$_init$f10d3ead4f9e91ce(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_scalar_ObjectIntMapper$method$_init$10c4521778ce6db6(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, struct _jc_object *, jint) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_scalar_ObjectIntMapper$method$_init$6f7527dce474d098(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_toolkits_scalar_ObjectIntMapper$method$add$c072c3c5381d46e2(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_toolkits_scalar_ObjectIntMapper$method$contains$d3bd70da40f05cb1(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_toolkits_scalar_ObjectIntMapper$method$getInt$36d310712392733a(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_ObjectIntMapper$method$getObject$a6a0b5ad3557b895(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_soot_toolkits_scalar_ObjectIntMapper$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_ObjectIntMapper$method_info$add$c072c3c5381d46e2;
extern _jc_method _jc_soot_toolkits_scalar_ObjectIntMapper$method_info$contains$d3bd70da40f05cb1;
extern _jc_method _jc_soot_toolkits_scalar_ObjectIntMapper$method_info$getInt$36d310712392733a;
extern _jc_method _jc_soot_toolkits_scalar_ObjectIntMapper$method_info$getObject$a6a0b5ad3557b895;
extern _jc_method _jc_soot_toolkits_scalar_ObjectIntMapper$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_ObjectIntMapper$vmethods {
	jint	(*add$c072c3c5381d46e2)(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jboolean	(*contains$d3bd70da40f05cb1)(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*getInt$36d310712392733a)(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getObject$a6a0b5ad3557b895)(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *, jint) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_toolkits_scalar_ObjectIntMapper$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_scalar_ObjectIntMapper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_ObjectIntMapper$vmethods	soot_toolkits_scalar_ObjectIntMapper;
};

// Vtype
struct _jc_soot_toolkits_scalar_ObjectIntMapper$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_ObjectIntMapper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_ObjectIntMapper$sub_refs {
	struct _jc_java_util_Vector$object	*intToObjects;
	struct _jc_object	*objectToInts;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_ObjectIntMapper$refs {
    _jc_soot_toolkits_scalar_ObjectIntMapper$sub_refs	soot_toolkits_scalar_ObjectIntMapper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_ObjectIntMapper$sub_nonrefs {
	jint	counter;
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_ObjectIntMapper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_ObjectIntMapper$sub_nonrefs	soot_toolkits_scalar_ObjectIntMapper;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_ObjectIntMapper$object {
	_jc_soot_toolkits_scalar_ObjectIntMapper$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_ObjectIntMapper$vtype	*vtype;
	_jc_soot_toolkits_scalar_ObjectIntMapper$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_ObjectIntMapper$vtype _jc_soot_toolkits_scalar_ObjectIntMapper$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_ObjectIntMapper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_ObjectIntMapper$class_object;

#endif	/* _JC_soot_toolkits_scalar_ObjectIntMapper_H_ */
